@@ -190,6 +190,15 @@ typedef struct {
   /** The login name of the user that owns this process */
   char userName[ 32 ];
 
+  /** NoNewPrivileges: task can't gain higher privileges via setuid etc. */
+  int noNewPrivileges;
+
+  /** cgroup: Linux process control group */
+  char cGroup[ 256 ];
+
+  /** Mandatory Access Control (SELinux or AppArmor) context */
+  char macContext[ 256 ];
+
 } ProcessInfo;
 
 void getIOnice( int pid, ProcessInfo *ps );
@@ -251,6 +260,8 @@ static bool getProcess( int pid, ProcessInfo *ps )
       sscanf( buf, "%*s %d", (int*)&ps->tracerpid );
       if (ps->tracerpid == 0)
           ps->tracerpid = -1; /* ksysguard uses -1 to indicate no tracerpid, but linux uses 0 */
+    } else if ( strcmp( tag, "NoNewPrivs:" ) == 0 ) {
+      sscanf( buf, "%*s %d", &ps->noNewPrivileges );
     }
   }
 
@@ -398,6 +409,32 @@ static bool getProcess( int pid, ProcessInfo *ps )
 
   getIOnice(pid, ps);
 
+  /* CGroups */
+  ps->cGroup[ 0 ] = '\0';
+  snprintf( buf, BUFSIZE - 1, "/proc/%d/cgroup", pid );
+  buf[ BUFSIZE - 1 ] = '\0';
+  if ( ( fd = fopen( buf, "r" ) ) != 0 )  {
+    do {
+         fgets( buf, BUFSIZE, fd );
+    } while ( !feof( fd ) && buf[0] != '0' );
+    fclose ( fd );
+
+    if ( buf[0] == '0' && buf[1] == ':' && buf[2] == ':' ) {
+      strncpy( ps->cGroup, &buf[3], sizeof( ps->cGroup ) - 1 );
+      ps->cGroup[ sizeof( ps->cGroup ) - 1 ] = '\0';
+      validateStr( ps->cGroup );
+    }
+  }
+
+  /* Mandatory Access Control (SELinux or AppArmor) context */
+  ps->macContext[ 0 ] = '\0';
+  snprintf( buf, BUFSIZE - 1, "/proc/%d/attr/current", pid );
+  if ( ( fd = fopen( buf, "r" ) ) != 0 )  {
+    if (fgets( ps->macContext, sizeof( ps->macContext ), fd ))
+      validateStr( ps->macContext );
+    fclose ( fd );
+  }
+
   return true;
 }
 
@@ -414,13 +451,13 @@ void printProcessList( const char* cmd)
       long pid;
       pid = atol( entry->d_name );
       if(getProcess( pid, &ps )) /* Print out the details of the process.  Because of a stupid bug in kde3 ksysguard, make sure cmdline and tty are not empty */
-        output( "%s\t%ld\t%ld\t%lu\t%lu\t%s\t%lu\t%lu\t%d\t%lu\t%lu\t%lu\t%s\t%ld\t%s\t%s\t%d\t%d\n",
+        output( "%s\t%ld\t%ld\t%lu\t%lu\t%s\t%lu\t%lu\t%d\t%lu\t%lu\t%lu\t%s\t%ld\t%s\t%s\t%d\t%d\t%d\t%s\t%s\n",
              ps.name, pid, (long)ps.ppid,
              (long)ps.uid, (long)ps.gid, ps.status, ps.userTime,
              ps.sysTime, ps.niceLevel, ps.vmSize, ps.vmRss, ps.vmURss,
              (ps.userName[0]==0)?" ":ps.userName, (long)ps.tracerpid,
              (ps.tty[0]==0)?" ":ps.tty, (ps.cmdline[0]==0)?" ":ps.cmdline,
-             ps.ioPriorityClass, ps.ioPriority
+             ps.ioPriorityClass, ps.ioPriority, ps.noNewPrivileges, ps.cGroup, ps.macContext
         );
     }
   }
@@ -491,8 +528,8 @@ void printProcessListInfo( const char* cmd )
 {
   (void)cmd;
   output( "Name\tPID\tPPID\tUID\tGID\tStatus\tUser Time\tSystem Time\tNice\tVmSize"
-                          "\tVmRss\tVmURss\tLogin\tTracerPID\tTTY\tCommand\tIO Priority Class\tIO Priority\n" );
-  output( "s\td\td\td\td\tS\td\td\td\tD\tD\tD\ts\td\ts\ts\td\td\n" );
+                          "\tVmRss\tVmURss\tLogin\tTracerPID\tTTY\tCommand\tIO Priority Class\tIO Priority\tNNP\tCGroup\tMAC Context\n" );
+  output( "s\td\td\td\td\tS\td\td\td\tD\tD\tD\ts\td\ts\ts\td\td\td\ts\ts\n" );
 }
 
 void printProcessCount( const char* cmd )
